@@ -5,23 +5,23 @@
 use strict;
 use warnings;
 
-use Error qw(:try);
+use Try::Tiny;
 use RT::Client::REST;
 use RT::Client::REST::Ticket;
 use Term::ReadKey;
 
-my $rt = RT::Client::REST->new(server => 'http://rt.cpan.org');
+my $rt = RT::Client::REST->new( server => 'http://rt.cpan.org' );
 
 my $dist = 'RT-Client-REST';    # This is the name of the queue.
 
-my ($username, $password);
+my ( $username, $password );
 
 print "RT Username: ";
-chomp($username = <>);
+chomp( $username = <> );
 
 print "RT Password: ";
 ReadMode 2;
-chomp($password = <>);
+chomp( $password = <> );
 ReadMode 0;
 
 $| = 1;
@@ -29,14 +29,17 @@ $| = 1;
 print "\nAuthenticating...";
 
 try {
-    $rt->login(username => $username, password => $password);
-} catch Exception::Class::Base with {
-    my $e = shift;
-    die ref($e), ": ", $e->message || $e->description, "\n";
+    $rt->login( username => $username, password => $password );
+}
+catch {
+    die $_ unless blessed $_ && $_->can('rethrow');
+    if ( $_->isa('Exception::Class::Base') ) {
+        die ref($_), ": ", $_->message || $_->description, "\n";
+    }
 };
 
 print "\nShort description of the problem (one line):\n";
-chomp(my $subject = <>);
+chomp( my $subject = <> );
 
 print "Long description (lone period or Ctrl-D to end):\n";
 my $description = '';
@@ -49,12 +52,13 @@ while (<>) {
 my $ticket;
 try {
     $ticket = RT::Client::REST::Ticket->new(
-        rt => $rt,
+        rt      => $rt,
         subject => $subject,
-        queue => $dist,
+        queue   => $dist,
     )->store;
-    $ticket->correspond(message => $description);
-} catch Exception::Class::Base with {
+    $ticket->correspond( message => $description );
+}
+catch Exception::Class::Base with {
     my $e = shift;
     die ref($e), ": ", $e->message || $e->description, "\n";
 };
